==> csgo-im-api-1.0.0.tgz: package/db.js <==
var DB = function(host, user, password, database){
  console.log('connecting to db...');
  this.mysql = require('mysql');

  this.connection;
  this.mysqlInfo = {
  	host     : host,
  	user     : user,
  	password : password,
  	database : database,
  	charset  : 'utf8_general_ci'
  };

  this.handleDisconnect();
}

DB.prototype.handleDisconnect = function(){
  this.connection = this.mysql.createConnection(this.mysqlInfo);

	this.connection.connect(function(err) {
		if(err) {
		  console.log(err);
		  setTimeout(this.handleDisconnect, 2000);
		} else {
      console.log('connected to db');
    }
	}.bind(this));

	this.connection.on('error', function(err) {
		console.log(err);
		if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET') {
		  this.handleDisconnect();
		} else {
		  throw err;
		}
	}.bind(this));
}

DB.prototype.escape = function(string){
  string = string.toString();
  string = string.replace(/\\/g,'\\\\');
  string = string.replace(/\'/g,'\\\'');
  string = string.replace(/\"/g,'\\"');
  string = string.replace(/\0/g,'\\0');
  return string;
}

DB.prototype.countTransaction = function(steamid){
  this.connection.query('UPDATE users SET transcations = transcations + 1 WHERE steamid = \''+steamid+'\'', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
		}
	}.bind(this));
}

DB.prototype.notify = function(desc, actions, type, steamid, callback){
  this.connection.query('INSERT INTO `notifications` (`desc`,`actions`,`type`,`steamid`,`time`) VALUES (\''+this.escape(desc)+'\',\''+JSON.stringify(actions)+'\',\''+this.escape(type)+'\',\''+this.escape(steamid)+'\',\''+Math.floor(Date.now()/1000)+'\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newUser = function(steamid, name, img, callback){
  this.connection.query('INSERT INTO `users` (`steamid`,`name`,`img`) VALUES (\''+this.escape(steamid)+'\',\''+this.escape(name)+'\',\''+this.escape(img)+'\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newApikey = function(apikey, public_key, steamid){
  this.connection.query('INSERT INTO `apikeys` (`apikey`,`public_key`,`steamid`,`requests_max`,`scopes`,`expire`) VALUES (\''+this.escape(apikey)+'\',\''+this.escape(public_key)+'\',\''+this.escape(steamid)+'\',\'30\',\'inventories,\',\'2147483647\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
		}
	}.bind(this));
}

DB.prototype.newInvoice = function(rid, steamid, amount, type, url, params){
  this.connection.query('INSERT INTO `invoices` (`rid`,`steamid`,`amount`,`type`,`url`,`params`) VALUES (\''+this.escape(rid)+'\',\''+this.escape(steamid)+'\',\''+this.escape(amount)+'\',\''+this.escape(type)+'\',\''+JSON.stringify(url)+'\',\''+JSON.stringify(params)+'\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
		}
	}.bind(this));
}

DB.prototype.newItem = function(assetid, name, img, bot, status, steamid, tradeofferid, callback){
  this.connection.query('INSERT INTO `items` (`assetid`,`name`,`img`,`bot`, `status`, `steamid`, `tradeofferid`) VALUES (\''+this.escape(assetid)+'\',\''+this.escape(name)+'\',\''+this.escape(img)+'\',\''+this.escape(bot)+'\', \''+this.escape(status)+'\', \''+this.escape(steamid)+'\', \''+this.escape(tradeofferid)+'\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newTrade = function(tradeofferid, token, items, state, bot, steamid, type, apikey, callback){
  this.connection.query('INSERT INTO `trades` (`tradeofferid`,`token`,`items`,`state`, `bot`, `steamid`, `type`, `apikey`) VALUES (\''+this.escape(tradeofferid)+'\',\''+this.escape(token)+'\',\''+JSON.stringify(items)+'\',\''+this.escape(state)+'\', \''+this.escape(bot)+'\', \''+this.escape(steamid)+'\', \''+this.escape(type)+'\', \''+this.escape(apikey)+'\')', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newTransfer = function(items, from, to, status, salt, token, apikey, callback){
  this.connection.query('INSERT INTO `transfers` (`items`,`from`,`to`,`status`,`salt`,`token`,`apikey`) VALUES (\''+JSON.stringify(items)+'\',\''+this.escape(from)+'\',\''+this.escape(to)+'\',\''+this.escape(status)+'\',\''+this.escape(salt)+'\',\''+this.escape(token)+'\',\''+this.escape(apikey)+'\')', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newBatch = function(type, items, bot, status, tradeofferid, callback){
  this.connection.query('INSERT INTO `batches` (`type`,`items`,`bot`,`action`, `status`, `tradeoffeid`, `time_created`) VALUES (\''+this.escape(type)+'\',\''+JSON.stringify(items)+'\',\''+this.escape(bot)+'\',\''+JSON.stringify(action)+'\', \''+this.escape(status)+'\', \''+this.escape(tradeoffeid)+'\', \''+this.escape(Math.floor(Date.now()/1000))+'\')', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.update = function(query, callback){
  this.connection.query(query, function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, true);
    }
	}.bind(this));
}

DB.prototype.select = function(query, callback){
  this.connection.query(query, function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else if(row && row.length > 0){
      callback(null, row);
    } else {
      callback(null, []);
    }
	}.bind(this));
}

DB.prototype.returnItems = function(items){
  for(var key in items){
    this.connection.query('UPDATE items SET status = 0 WHERE id = \''+items[key]+'\'', function(err, row, fields) {}.bind(this));
  }
}

module.exports = DB;

==> csgo-im-api-1.1.1.tgz: package/db.js <==
var DB = function(host, user, password, database){
  console.log('connecting to db...');
  this.mysql = require('mysql');

  this.connection;
  this.mysqlInfo = {
  	host     : host,
  	user     : user,
  	password : password,
  	database : database,
  	charset  : 'utf8_general_ci'
  };

  this.handleDisconnect();
}

DB.prototype.handleDisconnect = function(){
  this.connection = this.mysql.createConnection(this.mysqlInfo);

	this.connection.connect(function(err) {
		if(err) {
		  console.log(err);
		  setTimeout(this.handleDisconnect, 2000);
		} else {
      console.log('connected to db');
    }
	}.bind(this));

	this.connection.on('error', function(err) {
		console.log(err);
		if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET') {
		  this.handleDisconnect();
		} else {
		  throw err;
		}
	}.bind(this));
}

DB.prototype.escape = function(string){
  string = string.toString();
  string = string.replace(/\\/g,'\\\\');
  string = string.replace(/\'/g,'\\\'');
  string = string.replace(/\"/g,'\\"');
  string = string.replace(/\0/g,'\\0');
  return string;
}

DB.prototype.countTransaction = function(steamid){
  this.connection.query('UPDATE users SET transcations = transcations + 1 WHERE steamid = \''+steamid+'\'', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
		}
	}.bind(this));
}

DB.prototype.notify = function(desc, actions, type, steamid, callback){
  this.connection.query('INSERT INTO `notifications` (`desc`,`actions`,`type`,`steamid`,`time`) VALUES (\''+this.escape(desc)+'\',\''+JSON.stringify(actions)+'\',\''+this.escape(type)+'\',\''+this.escape(steamid)+'\',\''+Math.floor(Date.now()/1000)+'\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newSlots = function(plan, slots, expire, steamid, cvc){
  this.connection.query('INSERT INTO `slots_subscriptions` (`plan`,`slots`,`expire`,`steamid`,`cvc`) VALUES (\''+this.escape(plan)+'\',\''+this.escape(slots)+'\',\''+this.escape(expire)+'\',\''+this.escape(steamid)+'\',\''+this.escape(cvc)+'\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
		}
	}.bind(this));
}

DB.prototype.newUser = function(steamid, name, img, callback){
  this.connection.query('INSERT INTO `users` (`steamid`,`name`,`img`) VALUES (\''+this.escape(steamid)+'\',\''+this.escape(name)+'\',\''+this.escape(img)+'\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newApikey = function(apikey, public_key, steamid){
  this.connection.query('INSERT INTO `apikeys` (`apikey`,`public_key`,`steamid`,`requests_max`,`scopes`,`expire`) VALUES (\''+this.escape(apikey)+'\',\''+this.escape(public_key)+'\',\''+this.escape(steamid)+'\',\'30\',\'inventories,\',\'2147483647\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
		}
	}.bind(this));
}

DB.prototype.newInvoice = function(rid, steamid, amount, type, url, params, callback){
  this.connection.query('INSERT INTO `invoices` (`rid`,`steamid`,`amount`,`type`,`url`,`params`) VALUES (\''+this.escape(rid)+'\',\''+this.escape(steamid)+'\',\''+this.escape(amount)+'\',\''+this.escape(type)+'\',\''+JSON.stringify(url)+'\',\''+JSON.stringify(params)+'\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
      callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newItem = function(assetid, name, img, bot, status, steamid, tradeofferid, callback){
  this.connection.query('INSERT INTO `items` (`assetid`,`name`,`img`,`bot`, `status`, `steamid`, `tradeofferid`) VALUES (\''+this.escape(assetid)+'\',\''+this.escape(name)+'\',\''+this.escape(img)+'\',\''+this.escape(bot)+'\', \''+this.escape(status)+'\', \''+this.escape(steamid)+'\', \''+this.escape(tradeofferid)+'\') ', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newTrade = function(tradeofferid, token, items, state, bot, steamid, type, apikey, callback){
  this.connection.query('INSERT INTO `trades` (`tradeofferid`,`token`,`items`,`state`, `bot`, `steamid`, `type`, `apikey`) VALUES (\''+this.escape(tradeofferid)+'\',\''+this.escape(token)+'\',\''+JSON.stringify(items)+'\',\''+this.escape(state)+'\', \''+this.escape(bot)+'\', \''+this.escape(steamid)+'\', \''+this.escape(type)+'\', \''+this.escape(apikey)+'\')', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newTransfer = function(items, from, to, status, salt, token, apikey, callback){
  this.connection.query('INSERT INTO `transfers` (`items`,`from`,`to`,`status`,`salt`,`token`,`apikey`) VALUES (\''+JSON.stringify(items)+'\',\''+this.escape(from)+'\',\''+this.escape(to)+'\',\''+this.escape(status)+'\',\''+this.escape(salt)+'\',\''+this.escape(token)+'\',\''+this.escape(apikey)+'\')', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.newBatch = function(type, items, bot, status, tradeofferid, callback){
  this.connection.query('INSERT INTO `batches` (`type`,`items`,`bot`,`action`, `status`, `tradeoffeid`, `time_created`) VALUES (\''+this.escape(type)+'\',\''+JSON.stringify(items)+'\',\''+this.escape(bot)+'\',\''+JSON.stringify(action)+'\', \''+this.escape(status)+'\', \''+this.escape(tradeoffeid)+'\', \''+this.escape(Math.floor(Date.now()/1000))+'\')', function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, row);
    }
	}.bind(this));
}

DB.prototype.update = function(query, callback){
  this.connection.query(query, function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else {
      callback(null, true);
    }
	}.bind(this));
}

DB.prototype.select = function(query, callback){
  this.connection.query(query, function(err, row, fields) {
		if(err) {
 		  if(err.code === 'PROTOCOL_CONNECTION_LOST' || err.code === 'ECONNRESET'){
        this.handleDisconnect();
      }
			callback(err, null);
		} else if(row && row.length > 0){
      callback(null, row);
    } else {
      callback(null, []);
    }
	}.bind(this));
}

DB.prototype.returnItems = function(items){
  for(var key in items){
    this.connection.query('UPDATE items SET status = 0 WHERE id = \''+items[key]+'\'', function(err, row, fields) {}.bind(this));
  }
}

module.exports = DB;
